@@ -36,11 +36,11 @@ from easydev.misc import cmd_exists
 import subprocess
 
 import colorlog
+
 logger = colorlog.getLogger(__name__)
 
 
-
-__all__ = ['StatsBAM2Mapped', 'bam_to_mapped_unmapped_fastq', "GZLineCounter"]
+__all__ = ["StatsBAM2Mapped", "bam_to_mapped_unmapped_fastq", "GZLineCounter"]
 
 
 class DataContainer(dict):
@@ -56,24 +56,28 @@ class DataContainer(dict):
     def to_html(self):
         pass
 
+
 try:
-    _translate = string.maketrans('ACGTacgt', 'TGCAtgca')
-    def bytes(x,dummy):
+    _translate = string.maketrans("ACGTacgt", "TGCAtgca")
+
+    def bytes(x, dummy):
         return x
+
+
 except:
-    _translate = bytes.maketrans(b'ACGTacgt', b'TGCAtgca')
+    _translate = bytes.maketrans(b"ACGTacgt", b"TGCAtgca")
 
 
 def reverse_complement(seq):
     # use hastag but for now, do it manually
     return seq.translate(_translate)[::-1]
 
+
 def reverse(seq):
     return seq[::-1]
 
 
 class StatsBAM2Mapped(DataContainer):
-
     def __init__(self, bamfile=None, wkdir=None, verbose=True):
         super(StatsBAM2Mapped, self).__init__(wkdir=wkdir)
         if bamfile.endswith(".bam"):
@@ -85,20 +89,22 @@ class StatsBAM2Mapped(DataContainer):
         data = self.data
 
         # TODO hardcoded word phix here ?
-        html = "Reads with Phix: %s %%<br>" % precision(data['contamination'], 3)
+        html = "Reads with Phix: %s %%<br>" % precision(data["contamination"], 3)
 
         # add HTML table
         if "R2_mapped" in data.keys():
-            df = pd.DataFrame({
-              'R1': [data['R1_mapped'], data['R1_unmapped']],
-              'R2': [data['R2_mapped'], data['R2_unmapped']]})
+            df = pd.DataFrame(
+                {
+                    "R1": [data["R1_mapped"], data["R1_unmapped"]],
+                    "R2": [data["R2_mapped"], data["R2_unmapped"]],
+                }
+            )
         else:
-            df = pd.DataFrame({
-              'R1': [data['R1_mapped'], data['R1_unmapped']]})
-        df.index = ['mapped', 'unmapped']
+            df = pd.DataFrame({"R1": [data["R1_mapped"], data["R1_unmapped"]]})
+        df.index = ["mapped", "unmapped"]
 
-        html += "Unpaired: %s <br>" % data['unpaired']
-        html += "duplicated: %s <br>" % data['duplicated']
+        html += "Unpaired: %s <br>" % data["unpaired"]
+        html += "duplicated: %s <br>" % data["duplicated"]
         return html
 
 
@@ -121,7 +127,7 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
     In the paired-end case, 4 files are created.
 
     Note that this function is efficient in that it does not create intermediate
-    files limiting IO in the process. As compared to standard tools such as 
+    files limiting IO in the process. As compared to standard tools such as
     bedtools bamtofastq, it is 1.5 to 2X slower but it does create the mapped
     AND unmapped reads.
 
@@ -148,7 +154,7 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
 
 
     .. note:: the mapped reads may not be synchronized because we include also
-        the chimeric alignment (cf samtools documentation). However, 
+        the chimeric alignment (cf samtools documentation). However,
         total reads = unmappeds reads + R1 mapped + R2 mapped - supplementary
         reads (those with flag 2048).
     """
@@ -158,9 +164,10 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
     newname, ext = os.path.splitext(filename)
 
     import collections
+
     stats = collections.defaultdict(int)
-    stats['R1_unmapped'] = 0
-    stats['R1_mapped'] = 0
+    stats["R1_unmapped"] = 0
+    stats["R1_mapped"] = 0
 
     # figure out where to save the file
     if output_directory is None:
@@ -168,6 +175,7 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
     else:
         assert isinstance(filename, str)
         from sequana_pipetools.snaketools import FileFactory
+
         ff = FileFactory(filename)
         newname = output_directory + os.sep + ff.filenames[0]
 
@@ -176,26 +184,27 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
 
     R1_mapped = open(newname + "{}.mapped.fastq".format(rt1), "wb")
     R1_unmapped = open(newname + "{}.unmapped.fastq".format(rt1), "wb")
-    stats['duplicated'] = 0
-    stats['unpaired'] = 0
+    stats["duplicated"] = 0
+    stats["unpaired"] = 0
 
     unpaired = 0
 
     # if paired, let open other files
     if bam.is_paired:
-        stats['mode'] = "pe"
-        stats['R2_unmapped'] = 0
-        stats['R2_mapped'] = 0
+        stats["mode"] = "pe"
+        stats["R2_unmapped"] = 0
+        stats["R2_mapped"] = 0
         R2_mapped = open(newname + "{}.mapped.fastq".format(rt2), "wb")
         R2_unmapped = open(newname + "{}.unmapped.fastq".format(rt2), "wb")
     else:
-        stats['mode'] = "se"
+        stats["mode"] = "se"
 
     # loop through the BAM (make sure it is rewinded)
     bam.reset()
 
     if verbose:
         from easydev import Progress
+
         pb = Progress(len(bam))
 
     for i, this in enumerate(bam):
@@ -208,9 +217,9 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
             # A secondary alignment occurs when a given read could align reasonably well to
             # more than one place. One of the possible reported alignments is termed "primary"
             # and the others will be marked as "secondary".
-            stats['secondary'] += 1
+            stats["secondary"] += 1
             if this.is_paired is False:
-                stats['unpaired'] += 1
+                stats["unpaired"] += 1
         else:
 
             # quick hack
@@ -225,57 +234,57 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, verbose=True):
                 revcomp = reverse_complement(this.seq)
                 txt += bytes(revcomp, "utf-8") + b"\n"
                 txt += b"+\n"
-                txt += bytes(this.qual[::-1], 'utf-8') + b"\n"
+                txt += bytes(this.qual[::-1], "utf-8") + b"\n"
             else:
                 txt = b"@" + bytes(this.qname, "utf-8") + suffix + b"\n"
                 txt += bytes(this.seq, "utf-8") + b"\n"
                 txt += b"+\n"
-                txt += bytes(this.qual,"utf-8") + b"\n"
+                txt += bytes(this.qual, "utf-8") + b"\n"
 
             # Here, we must be careful as to keep the pairs. So if R1 is mapped
             # but R2 is unmapped (or the inverse), then the pair is mapped
             if this.is_read1:
                 if this.is_unmapped and this.mate_is_unmapped:
                     R1_unmapped.write(txt)
-                    stats['R1_unmapped'] += 1
+                    stats["R1_unmapped"] += 1
                 else:
                     R1_mapped.write(txt)
-                    stats['R1_mapped'] += 1
+                    stats["R1_mapped"] += 1
             elif this.is_read2:
                 if this.is_unmapped and this.mate_is_unmapped:
                     R2_unmapped.write(txt)
-                    stats['R2_unmapped'] += 1
+                    stats["R2_unmapped"] += 1
                 else:
                     R2_mapped.write(txt)
-                    stats['R2_mapped'] += 1
+                    stats["R2_mapped"] += 1
             else:
                 # This should be a single read
-                #assert self.is_paired is False
-                stats['unpaired'] += 1
+                # assert self.is_paired is False
+                stats["unpaired"] += 1
                 if this.is_unmapped:
                     R1_unmapped.write(txt)
-                    stats['R1_unmapped'] += 1
+                    stats["R1_unmapped"] += 1
                 else:
                     R1_mapped.write(txt)
-                    stats['R1_mapped'] += 1
+                    stats["R1_mapped"] += 1
 
             if this.is_duplicate:
-                stats['duplicated'] += 1
+                stats["duplicated"] += 1
 
         if verbose:
-            pb.animate(i+1)
+            pb.animate(i + 1)
 
     if bam.is_paired:
         R2_mapped.close()
         R2_unmapped.close()
 
-    logger.info("\nNumber of entries in the BAM: %s" % str(i+1))
+    logger.info("\nNumber of entries in the BAM: %s" % str(i + 1))
 
     R1_mapped.close()
     R1_unmapped.close()
 
-    _x = stats['R1_mapped']
-    _y = stats['R1_unmapped']
+    _x = stats["R1_mapped"]
+    _y = stats["R1_unmapped"]
     stats["contamination"] = _x / float(_x + _y) * 100
 
     return stats
@@ -301,13 +310,11 @@ def bam_get_paired_distance(filename):
     distances = []
 
     for fragment in b:
-        if fragment.is_unmapped is False and fragment.mate_is_unmapped is False \
-            and fragment.is_read1:
+        if not fragment.is_unmapped and not fragment.mate_is_unmapped and fragment.is_read1:
 
             # get the mate:
             mate = next(b)
 
-
             if fragment.is_reverse:
                 position2 = fragment.reference_end
                 position1 = mate.reference_start
@@ -316,7 +323,7 @@ def bam_get_paired_distance(filename):
                 position1 = fragment.reference_start
                 position2 = mate.reference_end
                 mode = 2
-            else: # if both are not reversed, what does that mean.
+            else:  # if both are not reversed, what does that mean.
                 # On Hm2, this is the case for 4 pairs out of 1622
                 # This seems to be a special case for fragment ends exactly
                 # at the end of the reference and mate starts exactly at
@@ -332,6 +339,18 @@ def bam_get_paired_distance(filename):
     return distances
 
 
+def fast_gc_content(chrom):
+    """Returns men GC content on a sequence
+
+    Cope with lower and upper cases
+    if x or X are present, the final GC percentage ignores them.
+    """
+    L = len(chrom)
+    GC = chrom.count("G") + chrom.count("C") + chrom.count("c") + chrom.count("g")
+    xX = chrom.count("X") + chrom.count("x")
+    return GC / (L - xX)
+
+
 def _base_content(filename, window_size, letters, circular=False):
     # DOC: see gc_content
     fasta = FastxFile(filename)
@@ -339,14 +358,15 @@ def _base_content(filename, window_size, letters, circular=False):
     chrom_gc_content = dict()
     for chrom in fasta:
         mid = int(window_size / 2)
+
         # Create gc_content array
         gc_content = np.empty(len(chrom.sequence))
         gc_content[:] = np.nan
         if circular:
-            chrom.sequence = (chrom.sequence[-mid:] + chrom.sequence +
-                    chrom.sequence[:mid])
+            chrom.sequence = chrom.sequence[-mid:] + chrom.sequence + chrom.sequence[:mid]
             # Does not shift index of array
             mid = 0
+
         # Count first window content
         counter = Counter(chrom.sequence[0:window_size])
         gc_count = 0
@@ -354,6 +374,7 @@ def _base_content(filename, window_size, letters, circular=False):
             gc_count += counter[letter]
 
         gc_content[mid] = gc_count
+
         for i in range(1, len(chrom.sequence) - window_size + 1):
             if chrom.sequence[i - 1] in checker:
                 gc_count -= 1
@@ -364,8 +385,7 @@ def _base_content(filename, window_size, letters, circular=False):
     return chrom_gc_content
 
 
-def gc_content(filename, window_size, circular=False, 
-        letters=['G', 'C', 'c', 'g']):
+def gc_content(filename, window_size, circular=False, letters=["G", "C", "c", "g"]):
     """Return GC content for the different sequences found in a FASTA file
 
     :param filename: fasta formated file
@@ -381,7 +401,7 @@ def gc_content(filename, window_size, circular=False,
 
 
 def genbank_features_parser(input_filename):
-    """ Return dictionary with features contains inside a genbank file.
+    """Return dictionary with features contains inside a genbank file.
 
     :param str input_filename: genbank formated file
     """
@@ -417,8 +437,8 @@ def genbank_features_parser(input_filename):
                     split_line = line.split()
                     t = split_line[0]
                     # Handle :
-                    #complement(order(1449596..1449640,1449647..1450684,
-                    #1450695..1450700))
+                    # complement(order(1449596..1449640,1449647..1450684,
+                    # 1450695..1450700))
                     positions = split_line[1]
                     if positions[0].isalpha():
                         while not line[:-1].endswith(")"):
@@ -429,12 +449,16 @@ def genbank_features_parser(input_filename):
                     start = pos[0]
                     end = pos[-1]
                     strand = "-" if split_line[1].startswith("c") else "+"
-                    new_feature = {"type": t, "gene_start": start,
-                            "gene_end": end, "strand": strand}
+                    new_feature = {
+                        "type": t,
+                        "gene_start": start,
+                        "gene_end": end,
+                        "strand": strand,
+                    }
 
                 # recover qualifier bound with feature
                 else:
-                    quali_line = line.strip().replace('"', '')
+                    quali_line = line.strip().replace('"', "")
                     if quali_line.startswith("/") and "=" in quali_line:
                         qualifier = quali_line.split("=")
                         key = qualifier[0][1:]
@@ -447,8 +471,6 @@ def genbank_features_parser(input_filename):
     return records
 
 
-
-
 class GZLineCounter(object):
     """Fast GZipped line counter
 
@@ -463,6 +485,7 @@ class GZLineCounter(object):
         100
 
     """
+
     def __init__(self, filename):
         self.filename = filename
         if cmd_exists("zcat"):
@@ -480,7 +503,7 @@ class GZLineCounter(object):
         i = 0
         p = subprocess.Popen(["zcat", self.filename], stdout=subprocess.PIPE)
         for line in p.stdout:
-            i +=1
+            i += 1
         return i
 
     """twice as fast as the other method below but large memory print
@@ -489,6 +512,7 @@ class GZLineCounter(object):
             data = gz_file.read()
         return len(data.splitlines())
     """
+
     def _use_gzip(self):
         i = 0
         with gzip.open(self.filename) as gz_file:
@@ -501,25 +525,24 @@ class GZLineCounter(object):
 def entropy(x):
     letters = set(x)
     from pylab import log
-    pi = [x.count(l)/float(len(x)) for l in letters]
-    pi = [x for x in pi if x!=0]
-    return -sum(pi*log(pi))
-
 
+    pi = [x.count(l) / float(len(x)) for l in letters]
+    pi = [x for x in pi if x != 0]
+    return -sum(pi * log(pi))
 
 
 class PairedFastQ(object):
-
     def __init__(self, fq1, fq2):
         self.fq1 = fq1
         self.fq2 = fq2
 
     def is_synchronised(self):
         from sequana import FastQ
+
         N = 0
         for a, b in zip(FastQ(self.fq1), FastQ(self.fq2)):
-            a = a['identifier'].decode()
-            b = b['identifier'].decode()
+            a = a["identifier"].decode()
+            b = b["identifier"].decode()
             a = a.split()[0]
             b = b.split()[0]
 
